@@ -32,7 +32,7 @@ setClass(Class = "RawDataParameters", representation = representation(data = "ma
 setMethod("show", "MetaboSet", function(object){
 	cat("A \"MetaboSet\" object containing", length(object@Data@FactorList), "samples \n \n" ,sep=" ")
 	cat("Data processed with", object@Data@Parameters$algorithm, "\n" ,sep=" ")
-	cat("Info attached for this experiment: \n", object@Info)
+	cat("Info attached to this experiment: \n", object@Info)
 })
 
 metaData <- function(object) {object@MetaData@Instrumental}
@@ -114,17 +114,15 @@ newExp <- function(instrumental, phenotype=NULL, info=character())
 		if(length(apply(as.matrix(colnames(MS.MetaData@Instrumental)),1,function(x) grep(col.correct[i],x)))==0) stop("Invalid instrumental file. The file must contain at least the following columns: ", paste(col.correct, collapse=", "))
 
 	# Phenotype Slots validation:
-	if(!is.null(MS.MetaData@Phenotype))
-	{
-	col.correct <- c("sampleID","class")
-	for(i in 1:length(col.correct))
-		if(length(apply(as.matrix(colnames(MS.MetaData@Phenotype)),1,function(x) grep(col.correct[i],x)))==0) stop("Invalid phenotype file. The file must contain at least the following columns: ", paste(col.correct, collapse=", "))
+	if(nrow(MS.MetaData@Phenotype)!=0){
+		col.correct <- c("sampleID","class")
+		for(i in 1:length(col.correct)) if(length(apply(as.matrix(colnames(MS.MetaData@Phenotype)),1,function(x) grep(col.correct[i],x)))==0) stop("Invalid phenotype file. The file must contain at least the following columns: ", paste(col.correct, collapse=", "))
 	}
 	sample.container <- new("MetaboSet", Info = info, Data = MS.Data, MetaData = MS.MetaData, Results = MS.Results)
 	sample.container
 }
 
-deconvolveComp <- function(Experiment, decParameters, samples.to.process=NULL)
+deconvolveComp <- function(Experiment, decParameters, samples.to.process=NULL, down.sample=FALSE, virtual.scans.ps=NULL)
 {
 	plotting=FALSE
 	Number.of.Samples <- nrow(Experiment@MetaData@Instrumental)
@@ -138,7 +136,7 @@ deconvolveComp <- function(Experiment, decParameters, samples.to.process=NULL)
 	for(index in samples.to.process)
 	{
 		cat("\n Deconvolving compounds from",as.character(Experiment@MetaData@Instrumental$filename[index]),"... Processing", k,"/",length(samples.to.process),"\n")  
-		Experiment <- processSample(Experiment, index, plotting)
+		Experiment <- processSample(Experiment, index, plotting, down.sample, virtual.scans.ps)
 		k <- k + 1
 	}
 	cat("\n Compounds deconvolved \n")
@@ -262,7 +260,7 @@ identifyComp <- function(Experiment, id.database=mslib, mz.range=NULL, n.putativ
 	Experiment
 }
 
-processSample <- function(Experiment, index, plotting)
+processSample <- function(Experiment, index, plotting, down.sample, virtual.scans.ps)
 {
 	if(Experiment@MetaData@DataDirectory=="") {filename <- as.character(Experiment@MetaData@Instrumental$filename[index])
 		}else{filename <- paste(Experiment@MetaData@DataDirectory,"/",Experiment@MetaData@Instrumental$filename[index], sep="")}
@@ -294,7 +292,7 @@ processSample <- function(Experiment, index, plotting)
 	
 	
 		sampleObject <- avoid.processing(sampleObject)
-		factor.list <- try(get.factor.list(sampleObject, analysis.window=Experiment@Data@Parameters$analysis.time, plotting), silent=F)
+		factor.list <- try(get.factor.list(sampleObject, analysis.window=Experiment@Data@Parameters$analysis.time, plotting, down.sample, virtual.scans.ps), silent=F)
 		if(class(factor.list)=="try-error") {factor.list <- as.data.frame(NULL); warning("Unable to extract factors from ", Experiment@MetaData@Instrumental$filename[index], ". Data may be corrupted.", sep="")}
 		Experiment@Data@FactorList[[index]] <- factor.list		
 	
